@@ -173,7 +173,7 @@ void POACCD::workerStreamVideo(const std::atomic_bool &isAbortToQuit)
     ret = POAStartExposure(mCameraInfo.cameraID, POA_FALSE);
     if (ret != POA_OK)
         LOGF_ERROR("Failed to start video capture (%s).", Helpers::toString(ret));
-    
+
 #ifdef ASI_LEGACY
     while (!isAbortToQuit)
     {
@@ -212,7 +212,7 @@ void POACCD::workerStreamVideo(const std::atomic_bool &isAbortToQuit)
         while(pIsReady == POA_FALSE)
         {
             if (isAbortToQuit) break;
-                
+
             POAImageReady(mCameraInfo.cameraID, &pIsReady);
         }
         if (isAbortToQuit) break;
@@ -228,15 +228,15 @@ void POACCD::workerStreamVideo(const std::atomic_bool &isAbortToQuit)
             }
             continue;
         }
-        
+
         if (mCurrentVideoFormat == POA_RGB24)
             for (uint32_t i = 0; i < totalBytes; i += 3)
                 std::swap(targetFrame[i], targetFrame[i + 2]);
-        
+
         Streamer->newFrame(targetFrame, totalBytes);
     }
 #endif
-    
+
     // stop video capture
     POAStopExposure(mCameraInfo.cameraID);
 }
@@ -267,7 +267,7 @@ void POACCD::workerBlinkExposure(const std::atomic_bool &isAbortToQuit, int blin
             LOGF_ERROR("Failed to start blink exposure (%s).", Helpers::toString(ret));
             break;
         }
-        
+
 #ifdef ASI_LEGACY
         POACameraState status = STATE_EXPOSING;
         do
@@ -282,7 +282,7 @@ void POACCD::workerBlinkExposure(const std::atomic_bool &isAbortToQuit, int blin
 
         POABool pIsReady = POA_FALSE;
         POAImageReady(mCameraInfo.cameraID, &pIsReady);
-        
+
         if (pIsReady != POA_TRUE)
         {
             LOGF_ERROR("Blink exposure failed, status %d (%s).", status, Helpers::toString(ret));
@@ -293,7 +293,7 @@ void POACCD::workerBlinkExposure(const std::atomic_bool &isAbortToQuit, int blin
         while(pIsReady == POA_FALSE)
         {
             if (isAbortToQuit) return;
-            
+
             ret = POAImageReady(mCameraInfo.cameraID, &pIsReady);
             if (ret != POA_OK)
             {
@@ -325,7 +325,7 @@ void POACCD::workerExposure(const std::atomic_bool &isAbortToQuit, float duratio
     PrimaryCCD.setExposureDuration(duration);
 
     LOGF_DEBUG("StartExposure->setexp : %.3fs", duration);
-    
+
     confVal.intValue = (long)(duration * 1000 * 1000);
     ret = POASetConfig(mCameraInfo.cameraID, POA_EXPOSURE, confVal, POA_FALSE);
     if (ret != POA_OK)
@@ -347,7 +347,7 @@ void POACCD::workerExposure(const std::atomic_bool &isAbortToQuit, float duratio
         // JM 2020-02-17 Special hack for older ASI120 and ASI130 cameras (USB 2.0)
         // that fail on 16bit images.
         if (getImageType() == POA_RAW16 &&
-            (strstr(getDeviceName(), "ASI120") || (strstr(getDeviceName(), "ASI130"))))
+                (strstr(getDeviceName(), "ASI120") || (strstr(getDeviceName(), "ASI130"))))
         {
             LOG_INFO("Switching to 8-bit video.");
             setVideoFormat(POA_RAW8);
@@ -375,7 +375,7 @@ void POACCD::workerExposure(const std::atomic_bool &isAbortToQuit, float duratio
     int statRetry = 0;
     POACameraState status = STATE_EXPOSING;
     POABool pIsReady = POA_FALSE;
-    
+
     do
     {
         if (isAbortToQuit)
@@ -435,7 +435,7 @@ void POACCD::workerExposure(const std::atomic_bool &isAbortToQuit, float duratio
             PrimaryCCD.setExposureFailed();
             return;
         }
-        
+
         POAImageReady(mCameraInfo.cameraID, &pIsReady);
     }
     while (pIsReady != POA_TRUE);
@@ -597,12 +597,15 @@ bool POACCD::updateProperties()
             {
                 for (size_t i = 0; i < VideoFormatSP.size(); i++)
                 {
+                    CaptureFormatSP[i].setState(ISS_OFF);
                     if (mCameraInfo.imgFormats[i] == POA_RAW16)
                     {
                         setVideoFormat(i);
+                        CaptureFormatSP[i].setState(ISS_ON);
                         break;
                     }
                 }
+                CaptureFormatSP.apply();
             }
         }
 
@@ -1218,7 +1221,7 @@ bool POACCD::UpdateCCDFrame(int x, int y, int w, int h)
         LOGF_ERROR("Failed to set ROI image format (%s).", Helpers::toString(ret));
         return false;
     }
-    
+
     ret = POASetImageStartPos(mCameraInfo.cameraID, subX, subY);
     if (ret != POA_OK)
     {
@@ -1346,18 +1349,19 @@ bool POACCD::isMonoBinActive()
     {
         return false;
     }
-    
+
     int width = 0, height = 0, bin = 1;
     POAImgFormat imgType = POA_RAW8;
     POAErrors ret1, ret2, ret3;
-    
+
     ret1 = POAGetImageSize(mCameraInfo.cameraID, &width, &height);
     ret2 = POAGetImageBin(mCameraInfo.cameraID, &bin);
     ret3 = POAGetImageFormat(mCameraInfo.cameraID, &imgType);
-    
+
     if (ret1 != POA_OK || ret2 != POA_OK || ret3 != POA_OK)
     {
-        LOGF_ERROR("Failed to get ROI format (%s, %s, %s).", Helpers::toString(ret1), Helpers::toString(ret2), Helpers::toString(ret3));
+        LOGF_ERROR("Failed to get ROI format (%s, %s, %s).", Helpers::toString(ret1), Helpers::toString(ret2),
+                   Helpers::toString(ret3));
         return false;
     }
 
@@ -1434,7 +1438,7 @@ IPState POACCD::guidePulse(INDI::Timer &timer, float ms, POAConfig dir)
     POASetConfig(mCameraInfo.cameraID, dir, confVal, POA_FALSE); // start to guide
 #endif
     LOGF_DEBUG("Starting %s guide for %f ms.", Helpers::toString(dir), ms);
-    
+
     timer.callOnTimeout([this, dir]
     {
 #ifdef ASI_LEGACY
@@ -1445,7 +1449,7 @@ IPState POACCD::guidePulse(INDI::Timer &timer, float ms, POAConfig dir)
         POASetConfig(mCameraInfo.cameraID, dir, confVal, POA_FALSE); // stop to guide
 #endif
         LOGF_DEBUG("Stopped %s guide.", Helpers::toString(dir));
-        
+
         if (dir == POA_GUIDE_NORTH || dir == POA_GUIDE_SOUTH)
             GuideComplete(AXIS_DE);
         else if (dir == POA_GUIDE_EAST || dir == POA_GUIDE_WEST)
@@ -1527,10 +1531,10 @@ void POACCD::createControls(int piNumberOfControls)
                    cap.isWritable ? "True" : "False");
 
         if (cap.isWritable == POA_FALSE || cap.configID == POA_TARGET_TEMP || cap.configID == POA_COOLER ||
-            cap.configID == POA_GUIDE_NORTH || cap.configID == POA_GUIDE_SOUTH ||
-            cap.configID == POA_GUIDE_EAST || cap.configID == POA_GUIDE_WEST ||
-            cap.configID == POA_FLIP_NONE || cap.configID == POA_FLIP_HORI ||
-            cap.configID == POA_FLIP_VERT || cap.configID == POA_FLIP_BOTH)
+                cap.configID == POA_GUIDE_NORTH || cap.configID == POA_GUIDE_SOUTH ||
+                cap.configID == POA_GUIDE_EAST || cap.configID == POA_GUIDE_WEST ||
+                cap.configID == POA_FLIP_NONE || cap.configID == POA_FLIP_HORI ||
+                cap.configID == POA_FLIP_VERT || cap.configID == POA_FLIP_BOTH)
             continue;
 
         // Update Min/Max exposure as supported by the camera
@@ -1685,3 +1689,8 @@ bool POACCD::saveConfigItems(FILE *fp)
 
     return true;
 }
+
+bool POACCD::SetCaptureFormat(uint8_t index)
+{
+    return setVideoFormat(index);
+}
